@@ -1,15 +1,13 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2016 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2016-2024 -- leonerd@leonerd.org.uk
 
-package Net::Prometheus::Types;
+package Net::Prometheus::Types 0.13;
 
-use strict;
+use v5.14;
 use warnings;
 
-our $VERSION = '0.12';
-
 use Exporter 'import';
 our @EXPORT_OK;
 
